require 'rails'
require 'rails/generators'
require 'rails/generators/active_record'

module ActiveRecord
  module Generators
    class MlangMigrationGenerator < Base
      source_root File.expand_path("../templates", __FILE__)
      argument :name, :type => :string, :default => "create_langs_table"

      def self.task_create
        raise 'Task unavailable to this database (no migration support)' unless ActiveRecord::Base.connection.supports_migrations?
        Rails.application.load_generators if Rails.application
        ActiveRecord::Generators::MlangMigrationGenerator.start [ ENV['MIGRATION'] || 'create_langs_table' ]
      end

      def self.task_clear
        ActiveRecord::Base.connection.execute "DELETE FROM #{ActiveRecord::Mlang::Lang.table_name};"
        ActiveRecord::Base.connection.execute "DELETE FROM #{ActiveRecord::Mlang::LangText.table_name};"
      end

      def create_migration_file
        migration_template "migration.rb", "db/migrate/#{file_name}.rb"
      end

      protected

      def lang_table_name
        current_table_name = ActiveRecord::Mlang::Lang.table_name
        if current_table_name == 'lang' || current_table_name == 'langs'
          current_table_name = ActiveRecord::Base.pluralize_table_names ? 'langs' : 'lang'
        end
        current_table_name
      end

      def lang_text_table_name
        current_table_name = ActiveRecord::Mlang::LangText.table_name
        if current_table_name == 'lang_text' || current_table_name == 'lang_texts'
          current_table_name = ActiveRecord::Base.pluralize_table_names ? 'lang_texts' : 'lang_text'
        end
        current_table_name
      end

    end
  end
end
